@@ -18,7 +18,6 @@ pub fn get_string(q: &str) -> String {
     }
 }
 
-// make the type same as varible
 pub fn get_int(q: &str) -> i32 {
     loop {
         print!("{}", q);
@@ -36,7 +35,7 @@ pub fn get_int(q: &str) -> i32 {
     }
 }
 
-pub fn get_float(q: &str) -> f64 {
+pub fn get_long(q: &str) -> i64 {
     loop {
         print!("{}", q);
         io::stdout().flush().unwrap();
@@ -53,3 +52,36 @@ pub fn get_float(q: &str) -> f64 {
     }
 }
 
+pub fn get_float(q: &str) -> f32 {
+    loop {
+        print!("{}", q);
+        io::stdout().flush().unwrap();
+    
+        let mut str = String::new();
+    
+        io::stdin().read_line(&mut str).ok();
+        let num = str.trim().parse();
+        let num = match num {
+            Ok(n) => n,
+            Err(_) => continue,
+        };
+        return num
+    }
+}
+
+pub fn get_double(q: &str) -> f64 {
+    loop {
+        print!("{}", q);
+        io::stdout().flush().unwrap();
+    
+        let mut str = String::new();
+    
+        io::stdin().read_line(&mut str).ok();
+        let num = str.trim().parse();
+        let num = match num {
+            Ok(n) => n,
+            Err(_) => continue,
+        };
+        return num
+    }
+}
\ No newline at end of file
